/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: crypt_p.h 870 2005-09-29 03:21:55Z aquamaniac $
 begin       : Thu Nov 06 2003
 copyright   : (C) 2003 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef GWENHYWFAR_CRYPT_P_H
#define GWENHYWFAR_CRYPT_P_H


#include "crypt_l.h"



struct GWEN_CRYPTKEY {
  GWEN_INHERIT_ELEMENT(GWEN_CRYPTKEY)
  GWEN_LIST_ELEMENT(GWEN_CRYPTKEY)
  GWEN_KEYSPEC *keyspec;
  GWEN_TYPE_UINT32 usage;
  void *keyData;
  int openCount;
  int pub;
  GWEN_TYPE_UINT32 flags;

  GWEN_CRYPTKEY_DUP_FN dupFn;
  GWEN_CRYPTKEY_ENCRYPT_FN encryptFn;
  GWEN_CRYPTKEY_DECRYPT_FN decryptFn;
  GWEN_CRYPTKEY_SIGN_FN signFn;
  GWEN_CRYPTKEY_VERIFY_FN verifyFn;
  GWEN_CRYPTKEY_GETCHUNKSIZE_FN getChunkSizeFn;
  GWEN_CRYPTKEY_FROMDB_FN fromDbFn;
  GWEN_CRYPTKEY_TODB_FN toDbFn;
  GWEN_CRYPTKEY_GENERATEKEY_FN generateKeyFn;
  GWEN_CRYPTKEY_FREEKEYDATA_FN freeKeyDataFn;
  GWEN_CRYPTKEY_OPEN_FN openFn;
  GWEN_CRYPTKEY_CLOSE_FN closeFn;

};

GWEN_CRYPTKEY *GWEN_CryptKey_List2__freeAll_cb(GWEN_CRYPTKEY *st, void
                                               *user_data);


struct GWEN_CRYPTKEY_PROVIDER {
  GWEN_CRYPTKEY_PROVIDER *next;
  char *name;
  GWEN_CRYPTPROVIDER_NEWKEY_FN newKeyFn;
};





#endif


